@@ -244,7 +244,7 @@ impl IRust {
         let EvalResult { output, status } = self.repl.eval_build(code.clone())?;
 
         if !status.success() {
-            Ok(format_err(&output))
+            Ok(format_err(&output, self.options.show_warnings))
         } else {
             self.repl.insert(code);
             success!()
@@ -315,24 +315,6 @@ impl IRust {
     }
 
     fn parse_second_order(&mut self) -> Result<PrintQueue> {
-        // these consts are used to detect statements that don't require to be terminated with ';'
-        // `loop` can return a value so we don't add it here, exp: `loop {break 4}`
-        const FUNCTION_DEF: &str = "fn ";
-        const ASYNC_FUNCTION_DEF: &str = "async fn ";
-        const ENUM_DEF: &str = "enum ";
-        const STRUCT_DEF: &str = "struct ";
-        const TRAIT_DEF: &str = "trait ";
-        const IMPL: &str = "impl ";
-        const PUB: &str = "pub ";
-        const WHILE: &str = "while ";
-        const EXTERN: &str = "extern ";
-        const MACRO_RULES: &str = "macro_rules!";
-
-        // attribute exp:
-        // #[derive(Debug)]
-        // struct B{}
-        const ATTRIBUTE: &str = "#";
-
         // Time irust compiling (includes rustc compiling + irust code)
         let timer = if self.options.compile_time {
             Some(Instant::now())
@@ -358,17 +340,30 @@ impl IRust {
             PrintQueue::default()
         } else if buffer_trimmed.ends_with(';')
             || self.options.auto_insert_semicolon
-                && (buffer_trimmed.starts_with(FUNCTION_DEF)
-                    || buffer_trimmed.starts_with(ASYNC_FUNCTION_DEF)
-                    || buffer_trimmed.starts_with(MACRO_RULES)
-                    || buffer_trimmed.starts_with(ENUM_DEF)
-                    || buffer_trimmed.starts_with(STRUCT_DEF)
-                    || buffer_trimmed.starts_with(TRAIT_DEF)
-                    || buffer_trimmed.starts_with(IMPL)
-                    || buffer_trimmed.starts_with(ATTRIBUTE)
-                    || buffer_trimmed.starts_with(PUB)
-                    || buffer_trimmed.starts_with(WHILE)
-                    || buffer_trimmed.starts_with(EXTERN))
+                // These patterns are used to detect statements that don't require to be terminated with ';'
+                // Note: `loop` can return a value so we don't add it here, exp: `loop {break 4}`
+                && match buffer_trimmed
+                    .split_whitespace()
+                    .collect::<Vec<_>>()
+                    .as_slice()
+                {
+                    // async fn|const fn|unsafe fn
+                    [_, "fn", ..]
+                    | ["fn", ..]
+                    | ["enum", ..]
+                    | ["struct", ..]
+                    | ["trait", ..]
+                    | ["impl", ..]
+                    | ["pub", ..]
+                    | ["extern", ..]
+                    | ["macro", ..] => true,
+                    | ["macro_rules!", ..] => true,
+                    // attribute exp:
+                    // #[derive(Debug)]
+                    // struct B{}
+                    [tag, ..] if tag.starts_with('#') => true,
+                    _ => false,
+                }
         {
             let mut print_queue = PrintQueue::default();
 
@@ -378,7 +373,9 @@ impl IRust {
                 self.while_compiling_hook();
                 let check_result = self.repl.eval_check(buffer.clone());
                 self.after_compiling_hook();
-                if let Some(mut e) = format_check_output(check_result?.output) {
+                if let Some(mut e) =
+                    format_check_output(check_result?.output, self.options.show_warnings)
+                {
                     print_queue.append(&mut e);
                     insert_flag = false;
                 }
@@ -410,7 +407,9 @@ impl IRust {
             }
 
             let output_prompt = self.get_output_prompt();
-            if let Some(mut eval_output) = format_eval_output(status, output, output_prompt) {
+            if let Some(mut eval_output) =
+                format_eval_output(status, output, output_prompt, self.options.show_warnings)
+            {
                 outputs.append(&mut eval_output);
             }
 
@@ -558,8 +557,13 @@ impl IRust {
 
         let output_prompt = self.get_output_prompt();
         // safe unwrap
-        Ok(format_eval_output(status.unwrap(), raw_out, output_prompt)
-            .ok_or("failed to bench function")?)
+        Ok(format_eval_output(
+            status.unwrap(),
+            raw_out,
+            output_prompt,
+            self.options.show_warnings,
+        )
+        .ok_or("failed to bench function")?)
     }
 
     fn bench(&mut self) -> Result<PrintQueue> {
